# 声明

This library has a lot of Chinese content, if you can't read the above two characters you can go.



# 更新日志
MixacLib 0.2.1

更改MixacLib.color的名称，防止与Arcade.color冲突


MixacLib 0.2.0

更新此readme文件

在更新同时安装的MixacLib 0.2.0可能会出现MixacLib.arcade_mixed()类，已删除



# 如何使用

## MixacLib.mcolor

### inf

输出Information内容

示例：MixacLib.mcolor.inf('内容')

输出：[信息]内容



### debug

输出调试信息

示例：MixacLib.mcolor.debug('内容')

输出：[调试]内容



### warn

输出警告信息

示例：MixacLib.mcolor.warn('内容')

输出：[警告]内容



### error

输出错误信息

示例：MixacLib.mcolor.error('内容')

输出：[错误]内容



### title

输出标题（仅装饰作用）

示例：MixacLib.mcolor.title('内容')

输出：内容



## MixacLib.cons

此部分主要基于console库

### title

设置控制台标题，当使用tkinter/PyQt图形化界面时无效

示例：MixacLib.cons.title('标题')

输出：

